C ********************************************************************
C * EDiT - Electronic Dipole-induced Transitions                     *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE CRYST                                                *
C *                                                                  *
C *  Routine of EDiT/CEDiT                                           *
C *  version for IBM-PC MS-DOS, Microsoft FORTRAN and                *
C *              IBM-RISC UNIX, AIX XL FORTRAN                       *
C *                                                                  *
C *  Usage......: Calculates the transition dipole length for tran-  *
C *               sitions in a crystal. Exactly the same SUBROUTINES *
C *               as in the molecular case are called. However, app- *
C *               ropriate coordinate manipulations has to be con-   *
C *               sidered.                                           *
C *                                                                  *
C *  Authors....: Ruedi Rytz                                         *
C *                                                                  *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: January 1996                                       *
C *  Revision...: -                                                  *
C *                                                                  *
C *  Called from: MATRIX                                             *
C *                                                                  *
C *  Calls......: DIAG, BDIAG, OBDIAG                                *
C *                                                                  *
C ********************************************************************

      SUBROUTINE CRYST(SUM,PSII,CPSII,PSIF,CPSIF,ANZAO,KP,DIM,NEIGH,
     .                 ANZATO,X,Y,Z,FAO,LAO,POL,NS,NP,ND,POINTER,
     .                 EXPS,EXPP,EXPD1,EXPD2,C1,C2)

      IMPLICIT NONE

      INCLUDE 'sizes'
      INCLUDE 'edconst.inc'

        DOUBLE PRECISION  SUM, PSII(MAXAO), CPSII(MAXAO) 
        DOUBLE PRECISION  PSIF(MAXAO), CPSIF(MAXAO)
        INTEGER           ANZAO
        DOUBLE PRECISION  KP(3), DIM(3,3)
        INTEGER           NEIGH(3), ANZATO
        DOUBLE PRECISION  X(MAXATO), Y(MAXATO), Z(MAXATO)
        DOUBLE PRECISION  FAO(MAXATO), LAO(MAXATO)
        CHARACTER*1       POL
        INTEGER           NS(MAXATO), NP(MAXATO), ND(MAXATO) 
        INTEGER           POINTER(MAXATO)
        DOUBLE PRECISION  EXPS(MAXATO), EXPP(MAXATO), EXPD1(MAXATO)
        DOUBLE PRECISION  EXPD2(MAXATO), C1(MAXATO), C2(MAXATO)
        

C VAR
   
      COMPLEX*16  MSUM(MAXAO,MAXAO), MC(MAXAO,MAXAO), CSUM

      DOUBLE PRECISION  M(MAXAO,MAXAO), K1, K2
      DOUBLE PRECISION  XTMP(MAXATO), YTMP(MAXATO) 
      DOUBLE PRECISION  ZTMP(MAXATO), OFFSET(3)
      INTEGER   I, J, N, O, P, R, S, T, DIV
      LOGICAL   SAME

C BEGIN
C
C Reset MSUM and CSUM
       CSUM = (0.0D0, 0.0D0)
       DO 4 I = 1, ANZAO
         DO 6 J = 1, ANZAO
           MSUM(I,J) = (0.0D0, 0.0D0)
6        CONTINUE
4      CONTINUE

       DO 10 N = -NEIGH(1), NEIGH(1)
C       DO 10 N = -NEIGH(1), 0
         DO 20 O = -NEIGH(2), NEIGH(2)
           DO 30 P = -NEIGH(3), NEIGH(3)
             DO 40 R = -NEIGH(1), NEIGH(1)
C             DO 40 R = -NEIGH(1), 0
               DO 50 S = -NEIGH(2), NEIGH(2)
                 DO 60 T = -NEIGH(3), NEIGH(3)

                   K1=TWOPI*(KP(1)*N + KP(2)*O + KP(3)*P)
                   K2=TWOPI*(KP(1)*R + KP(2)*S + KP(3)*T)

                   DO 70 I = 1, ANZAO
                     DO 80 J = 1, ANZAO
                       MC(I,J) = -CMPLX(0.D0,1.D0)*(PSIF(J)*
     .                 EXP(CMPLX(0.D0,1.D0)*K2)*CONJG(-CMPLX(0.D0,1.D0)*
     .                 EXP(CMPLX(0.D0,1.D0)*K1)*PSII(I)+CPSII(I)*
     .                 EXP(CMPLX(0.D0,1.D0)*K1))+CMPLX(0.D0,1.D0)*
     .                 CONJG(-CMPLX(0.D0,1.D0)*EXP(CMPLX(0.D0,1.D0)*K1)*
     .                 PSII(I)+CPSII(I)*EXP(CMPLX(0.D0,1.D0)*K1))*
     .                 EXP(CMPLX(0.D0,1.D0)*K2)*CPSIF(J))
                       IF ( ABS(MC(I,J)) .GT. 1.0D-8 ) THEN
                         M(I,J) = 1.0D0
                       ELSE
                         M(I,J) = 0.0D0
                       ENDIF
80                   CONTINUE
70                 CONTINUE


C As you see, we loop over ALL initial an final cells. For a crystal of
C dimension N this means N^3 calculations. So far we do not try to minimize the
C calculation time. This can be done in a second step. We are first only
C interested in the results. The diagonal and block-diagonal part of the
C calculation needs only to be done if final AND initial cell are the same.
C DIM contains the offset in Angstroms of two neighboring cells.

                   DO 100 I = 1, ANZATO
                     XTMP(I) = X(I) + N * DIM(1,1)
     .                              + O * DIM(2,1)
     .                              + P * DIM(3,1)
                     YTMP(I) = Y(I) + N * DIM(1,2)
     .                              + O * DIM(2,2)
     .                              + P * DIM(3,2)
                     ZTMP(I) = Z(I) + N * DIM(1,3)
     .                              + O * DIM(2,3)
     .                              + P * DIM(3,3)
100                CONTINUE  

                   SAME=.FALSE.
                   IF ( (N .EQ. R) .AND. 
     .                  (O .EQ. S) .AND. 
     .                  (P .EQ. T) ) THEN
                     SAME=.TRUE.

                     CALL DIAG(M, ANZATO, XTMP, YTMP, ZTMP, FAO, 
     .                         LAO, POL)

                     CALL BDIAG(M, ANZATO, FAO, LAO, POL, NS, NP,
     .                          POINTER, EXPS, EXPP, EXPD1, EXPD2,
     .                          C1, C2)
                     DO 110 I = 1,3
                       OFFSET(I) = 0.0D0
110                  CONTINUE
                   ELSE
                     OFFSET(1) = (R - N) * DIM(1,1)
     .                         + (S - O) * DIM(2,1)
     .                         + (T - P) * DIM(3,1)
                     OFFSET(2) = (R - N) * DIM(1,2)
     .                         + (S - O) * DIM(2,2)
     .                         + (T - P) * DIM(3,2)
                     OFFSET(3) = (R - N) * DIM(1,3) 
     .                         + (S - O) * DIM(2,3)
     .                         + (T - P) * DIM(3,3)
                   ENDIF

                   CALL OBDIAG(M, ANZATO, FAO, LAO, POL, NS, NP, ND,
     .                         POINTER, EXPS, EXPP, EXPD1, EXPD2,
     .                         C1, C2, XTMP, YTMP, ZTMP, SAME, OFFSET)

                  DIV = ( (2*NEIGH(1)+1) - ABS(N-R) ) *
     .                  ( (2*NEIGH(2)+1) - ABS(S-O) ) *
     .                  ( (2*NEIGH(3)+1) - ABS(T-P) ) 

C                  DIV = ( (NEIGH(1)+1) - ABS(N-R) ) *
C     .                  ( (NEIGH(2)+1) - ABS(S-O) ) *
C     .                  ( (NEIGH(3)+1) - ABS(T-P) ) 
             

                   DO 500 I = 1, ANZAO
                     DO 600 J = 1, ANZAO
                       MSUM(I,J) = MSUM(I,J) + (MC(I,J)*M(I,J))/DIV
600                  CONTINUE
500                CONTINUE
60               CONTINUE
50             CONTINUE
40           CONTINUE
30         CONTINUE
20       CONTINUE
10     CONTINUE

       SUM = 0.0D0
       DO 120 I = 1,ANZAO
         DO 130 J = I, ANZAO
           IF (I .EQ. J) THEN
              CSUM = CSUM + MSUM(I,J)
            ELSE
              CSUM = CSUM + MSUM(I,J) + MSUM(J,I)
            ENDIF
130       CONTINUE
120     CONTINUE

      SUM = ABS(CSUM)

      RETURN
      END   
C END
