! ********************************************************************
! * GOP - Graphic Optimization Program for EHMO ICONC                *
! *                                                                  *
! * Copyright (C) 1997 by Gion Calzaferri                            *
! *                                                                  *
! * This program is free software; you can redistribute it and/or    *
! * modify it under the terms of the GNU General Public License as   *
! * published by the Free Software Foundation; Version 2 of the      *
! * License.                                                         *
! *                                                                  *
! * This program is distributed in the hope that it will be useful,  *
! * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
! * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
! * General Public License for more details.                         *
! *                                                                  *
! * You should have received a copy of the GNU General Public        *
! * License along with this program; if not, write to the Free       *
! * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
! * MA 02111-1307 USA                                                *
! ********************************************************************


!------------------------------------------------------------------------------
! PROJECT : GOP                                            by Roman Calzaferri
!------------------------------------------------------------------------------
! FILENAME      : ENERTOT.f90
! AUTHOR        : Roman Calzaferri
! DATE          : 22. August 1997
! LAST MODIFIED : 15. September 1997
!------------------------------------------------------------------------------
! CONTENTS : 'Class' ENERTOT. Only one instance possible; nothing else will
!            ever be used. Accesses the 'enertot.dat'-file created by iconc 
!------------------------------------------------------------------------------
! USED BY  : ENERGY_FUNCTION, file ENERGY_FUNCTION_S.f90
!------------------------------------------------------------------------------
! USES     : -
!------------------------------------------------------------------------------


MODULE ENERTOT
   IMPLICIT NONE

   ! ----------------------------------- 
      CHARACTER(LEN=150), PRIVATE :: LINEBUFFER
      LOGICAL                     :: ENERTOT_OPENED

   ! ----------------------------------- 
   CONTAINS
      SUBROUTINE ENERTOT_OPEN(ERR)
         ! opens enertot.dat
         INTEGER, INTENT(OUT), OPTIONAL :: ERR
         INTEGER                           ERROR_STATE

         OPEN(1, FILE='ENERTOT.DAT', STATUS='OLD', IOSTAT = ERROR_STATE)
         IF (ERROR_STATE /= 0) THEN
            IF (PRESENT(ERR)) ERR = ERROR_STATE
            ENERTOT_OPENED = .FALSE.
            RETURN
         END IF

         ENERTOT_OPENED = .TRUE.
         READ(1, '(//)')        !skip three lines
         CALL ENERTOT_NEXTLINE  ! read in first line
      END SUBROUTINE ENERTOT_OPEN
      ! ----------------------------------- 

      SUBROUTINE ENERTOT_CLOSE
         IF (ENERTOT_OPENED)  THEN
            CLOSE(1)
            ENERTOT_OPENED = .FALSE.
         END IF
      END SUBROUTINE ENERTOT_CLOSE
      ! ----------------------------------- 

      SUBROUTINE ENERTOT_NEXTLINE
         ! reads in the next line of enertot.dat
         !------------------------------
         ! REQUIRES : ENERTOT_OPENED = TRUE
         !------------------------------
        IF (ENERTOT_OPENED)  READ(1, '(A)') LINEBUFFER
      END SUBROUTINE ENERTOT_NEXTLINE
      ! ----------------------------------- 

      FUNCTION ENERTOT_E_VAL
         !------------------------------
         ! REQUIRES : ENERTOT_OPENED = TRUE
         !------------------------------
         DOUBLE PRECISION ENERTOT_E_VAL
         CHARACTER(LEN=130) BUF

         READ(LINEBUFFER, '(A121,F16.8)') BUF, ENERTOT_E_VAL
      END FUNCTION ENERTOT_E_VAL
      ! ----------------------------------- 

END MODULE ENERTOT
! -----------------------------------
! end of file
! -----------------------------------



