! ********************************************************************
! * GOP - Graphic Optimization Program for EHMO ICONC                *
! *                                                                  *
! * Copyright (C) 1997 by Gion Calzaferri                            *
! *                                                                  *
! * This program is free software; you can redistribute it and/or    *
! * modify it under the terms of the GNU General Public License as   *
! * published by the Free Software Foundation; Version 2 of the      *
! * License.                                                         *
! *                                                                  *
! * This program is distributed in the hope that it will be useful,  *
! * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
! * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
! * General Public License for more details.                         *
! *                                                                  *
! * You should have received a copy of the GNU General Public        *
! * License along with this program; if not, write to the Free       *
! * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
! * MA 02111-1307 USA                                                *
! ********************************************************************


!------------------------------------------------------------------------------
! PROJECT : GOP                                            by Roman Calzaferri
!------------------------------------------------------------------------------
! FILENAME      : INPUTC_ICONC.f90
! AUTHOR        : Roman Calzaferri
! DATE          : 22. August 1997
! LAST MODIFIED : 12. September 1997
! WARNING       : NOT PORTABLE (see specials)
!------------------------------------------------------------------------------
! CONTENTS : procedure to call inputc and iconc with a specific .gen file
!------------------------------------------------------------------------------
! SPECIALS : this module uses the 'SYSTEM' function of the microsoft portlib-
!            library which is NOT FORTRAN 90 STANDARD! 
!            Therefore, this file needs to be changed if you want to port the 
!            program to any other system or compiler
!------------------------------------------------------------------------------
! USED BY  : ENERGY_FUNCTION_S, file ENERGY_FUNCTION.f90
!------------------------------------------------------------------------------
! USES     : Microsoft(R) FPS 4.0 PORTLIB library
!------------------------------------------------------------------------------


MODULE INPUTC_ICONC
   USE PORTLIB     !! for function 'SYSTEM'
                   !! THIS NEEDS TO BE REPLACED WHEN COMPILED ON OTHER 
                   !! PLATFORMS!
   IMPLICIT NONE


   !--------------------------------------------
   CONTAINS


   FUNCTION INPUTC_ICONC_EXECUTE(WITH_FILE)
      ! returns integer /= 0 if execution of inputc or of iconc failed
      CHARACTER(LEN=*), INTENT(IN) :: WITH_FILE          ! name of .gen file
      INTEGER                      :: INPUTC_ICONC_EXECUTE, ERR

      INPUTC_ICONC_EXECUTE = 0

      ERR = CALL_INPUTC(WITH_FILE)
      IF (ERR /= 0) THEN
         INPUTC_ICONC_EXECUTE = 1
         PRINT*, 'Unable to execute INPUTC. Please check path'
         RETURN
      END IF

      ERR = CALL_ICONC()
      IF (ERR /= 0) THEN
         INPUTC_ICONC_EXECUTE = 2
         PRINT*, 'Unable to execute ICONC. Please check path'
         RETURN
      END IF

      RETURN

      !--------------------------------------------
      ! internal procedures of INPUTC_ICONC_EXECUTE
      CONTAINS
         FUNCTION CALL_INPUTC(WITH_FILE)
            CHARACTER(LEN=*), INTENT(IN)    :: WITH_FILE       !name of .gen file
            CHARACTER(LEN=LEN(WITH_FILE))   :: WITH_FILES_NAME !same without ext.
            CHARACTER(LEN=*), PARAMETER     :: CALLFILE = 'IPCCAL.TMP'
            CHARACTER(LEN=10+LEN(CALLFILE)) :: CALL_TEXT
            INTEGER                         :: CALL_INPUTC, I
                        
            ! remove extension from filename
            DO I=1,LEN(WITH_FILE)
               IF (WITH_FILE(I:I)=='.') THEN
                  WITH_FILES_NAME(1:I-1) = WITH_FILE(1:I)
                  WITH_FILES_NAME(I:LEN(WITH_FILE)) = ' '
                  EXIT
               END IF
            END DO

            !create file with which to call INPUTC
            !(option = 3, name of .gen file = WITH_FILES_NAME)
            OPEN(UNIT=1, FILE=CALLFILE, STATUS='REPLACE')
            WRITE(1,'(I2,/,A,/)') 3, WITH_FILES_NAME
            CLOSE(1)

            WRITE(CALL_TEXT, '(A,A)') 'INPUTC < ', CALLFILE
            CALL_INPUTC = SYSTEM(CALL_TEXT)
            RETURN
         END FUNCTION CALL_INPUTC
         ! ----------------------------------- 

         FUNCTION CALL_ICONC
            INTEGER CALL_ICONC

            CALL_ICONC = SYSTEM('ICONC < temp.kar > temp.out')
            RETURN
         END FUNCTION CALL_ICONC
         !------------------------------------

   END FUNCTION INPUTC_ICONC_EXECUTE
   ! ----------------------------------- 

END MODULE INPUTC_ICONC
! ----------------------------------- 
! end of file
! ----------------------------------- 
