C ********************************************************************
C * ICONC - Extended Hueckel Calculations                            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE DESORB                                               *
C *                                                                  *
C *  Routine of ICONC(S)                                             *
C *                                                                  *
C *  Usage......: Calculates atomic orbital occupation numbers.      *
C *                                                                  *
C *  Authors....: -                                                  *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: -                                                  *
C *  Revision...: 02.06.92/mbs (Martin Braendle)                     *
C *  Remarks....: Earlier used to calculate part of orbital stabili- *
C *               zation energy (sum over AO occupation times Hii).  *
C *               The following method has been and is applied (by   *
C *               default, L9=FALSE):                                *
C *               All valence electrons are filled into the energe-  *
C *               tically lowest level until it is full, then the    *
C *               remaining electrons are filled in the next higher  *
C *               levels. This means that the Aufbau principle is    *
C *               used. As a consequence, in the case of transitio   *
C *               elements, the thus resulting electron configura-   *
C *               tion does in general not correspond to the elec-   *
C *               tron configuration of the free metal atom.         *
C *               In a proposed alternative method (L9=TRUE), the    *
C *               user can specify electron configurations. For the  *
C *               elements not specified the electron configuration  *
C *               of the free atom is used.                          *
C *               If charge iteration is applied we propose to use   *
C *               the Aufbau principle.                              *
C *               Remind: The obtained occupation numbers are used   *
C *               for both calculation of the orbital stabilization  *
C *               energy and the electrostatic two-body repulsion.   *
C *                                                                  *
C *  Called from: OUTPUT,REP                                         *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE DESORB(COUD,COUP,COUS,IATOM,IOCCS,IOCCP,IOCCD,KEYI)
 
      IMPLICIT REAL*8 (A-H,O-Z)
 
      INCLUDE 'iconpara.for'
 
      CHARACTER*2 ELENAM
 
      COMMON /AOOCC/NAOOCC,ICONF(MXAOOC,4)
 
      COMMON /ATOM/EXPS(MXATOM),EXPP(MXATOM),EXPD(MXATOM),EXPD2(MXATOM),
     .             C1(MXATOM),C2(MXATOM),COULS(MXATOM),COULP(MXATOM),
     .             COULD(MXATOM),X(MXATOM),Y(MXATOM),Z(MXATOM),
     .             KEY(MXATOM),AC(MXATOM),VELEC(MXATOM),NS(MXATOM),
     .             NP(MXATOM),ND(MXATOM)
      INTEGER AC,VELEC,KEY
 
      COMMON /CNTRL/CON,PEEP,COULH,NH,NA,NATM,KA,NELEC,METH,IPRINT,
     .              IPUNCH,L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
      LOGICAL*1 L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
 
      COMMON /STARS/STAR,STAR2,SYMBOL(MXATOM)
      CHARACTER*2 STAR,STAR2,SYMBOL
C
C ELESYM holds the names of the transition elements.
C IECONF holds their electronic configuration (s,p,d) of the free atom.
C 02.06.92/mbs
C
      CHARACTER*2 ELESYM(30)
      DIMENSION   IECONF(3,30)
 
      DATA ELESYM/'SC','TI',' V','CR','MN','FE','CO','NI','CU','ZN',
     .            ' Y','ZR','NB','MO','TC','RU','RH','PD','AG','CD',
     .            'LA','HF','TA',' W','RE','OS','IR','PT','AU','HG'/
      DATA IECONF/2,0,1, 2,0,2, 2,0,3, 1,0,5, 2,0,5, 2,0,6, 2,0,7,
     .            2,0,8, 1,0,10, 2,0,10,
     .            2,0,1, 2,0,2, 1,0,4, 1,0,5, 1,0,6, 1,0,7, 1,0,8,
     .            0,0,10, 1,0,10, 2,0,10,
     .            2,0,1, 2,0,2, 2,0,3, 2,0,4, 2,0,5, 2,0,6, 2,0,7,
     .            1,0,9, 1,0,10, 2,0,10/
 
      IVELE=VELEC(KEYI)
      ELENAM=SYMBOL(KEYI)
      IOCCS=0
      IOCCP=0
      IOCCD=0
 
      IF (L9) THEN
C
C Go first through user specified atomic electron configurations.
C
        IF (NAOOCC .GT. 0) THEN
          DO 10 I=1,NAOOCC
            IF (IATOM .EQ. ICONF(I,1)) THEN
              IOCCS=ICONF(I,2)
              IOCCP=ICONF(I,3)
              IOCCD=ICONF(I,4)
              RETURN
            ENDIF
10        CONTINUE
        ENDIF
C
C Check if there is a transition element.
C
        DO 20 I=1,30
          IF (ELENAM .EQ. ELESYM(I)) THEN
            IOCCS=IECONF(1,I)
            IOCCP=IECONF(2,I)
            IOCCD=IECONF(3,I)
            RETURN
          ENDIF
20      CONTINUE
C
C If no transition element is found, determine the electron configura-
C tion of the free atom in the order s (d) p.
C
        IOCCS=MIN(IVELE,2)
        IVELE=IVELE-IOCCS
        IF (ND(KEYI) .GT. 0) THEN
          IOCCD=10
          IVELE=IVELE-10
        ENDIF
        IOCCP=IVELE
      ELSE
C
C default method (Aufbau principle)
C
        IF (COUD .LE. COUP) THEN
          IF (COUD .LE. COUS) THEN
            IOCCD=MIN(IVELE,10)
            IVELE=IVELE-IOCCD
            IF ((COUP .LE. COUS) .AND. (IVELE .GT. 0)) THEN
              IOCCP=MIN(IVELE,6)
              IVELE=IVELE-IOCCP
              IOCCS=MIN(IVELE,2)
            ELSE
              IOCCS=MIN(IVELE,2)
              IVELE=IVELE-IOCCS
              IOCCP=MIN(IVELE,6)
            ENDIF
          ELSE
            IOCCS=MIN(IVELE,2)
            IVELE=IVELE-IOCCS
            IOCCD=MIN(IVELE,10)
            IVELE=IVELE-IOCCD
            IOCCP=MIN(IVELE,6)
          ENDIF
        ELSE
          IF (COUD .LE. COUS) THEN
            IOCCP=MIN(IVELE,6)
            IVELE=IVELE-IOCCP
            IOCCD=MIN(IVELE,10)
            IVELE=IVELE-IOCCD
            IOCCS=MIN(IVELE,2)
          ELSE
            IF (COUP .LE. COUS) THEN
              IOCCP=MIN(IVELE,6)
              IVELE=IVELE-IOCCP
              IOCCS=MIN(IVELE,2)
              IVELE=IVELE-IOCCS
              IOCCD=MIN(IVELE,10)
            ELSE
              IOCCS=MIN(IVELE,2)
              IVELE=IVELE-IOCCS
              IOCCP=MIN(IVELE,6)
              IVELE=IVELE-IOCCP
              IOCCD=MIN(IVELE,10)
            ENDIF
          ENDIF
        ENDIF
      ENDIF
 
      RETURN
      END
