C ********************************************************************
C * ICONC - Extended Hueckel Calculations                            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  PROGRAM ICONC                                                   *
C *                                                                  *
C *  Usage......: does Extended Huckel calculations with or without  *
C *               charge iteration                                   *
C *                                                                  *
C *  Authors....: origin by R.Hoffmann                               *
C *  Available..: Calzaferri group c/o                               *
C *               Department of Chemistry and Biochemistry           *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: -                                                  *
C *  Revision...: last revision 24.08.97/mbs (Martin Braendle)       *
C *  Remarks....: Variables for FMO specifications added.            *
C *               COMMON blocks KSET and OMITRP for special version  *
C *               of ICONC (individual k-parameter specification,    *
C *               omitting of atoms from repulsion energy calcula-   *
C *               tion) added.                                       *
C *                                                                  *
C *  Called from: -                                                  *
C *                                                                  *
C *  Calls......: INPUT                                              *
C *               MATRIX                                             *
C *                                                                  *
C ********************************************************************
 
      BLOCK DATA
      INCLUDE 'iconpara.for'
C
C  Parameter I0 is a number for DATA-statements.
C
      PARAMETER (I0=MXATOM-38)
      PARAMETER (MXITR1=MXITER+1)
C
C  Dimension for MXATOM atoms.
C  Initialization of internal atomic data. There are provisions
c  for MXATOM user defined atoms, 30 internally defined atoms, and
c  space for 10 more to be used either way.
C
      IMPLICIT REAL*8(A-H,O-Z)
 
      COMMON /ATOM/EXPS(MXATOM),EXPP(MXATOM),EXPD(MXATOM),EXPD2(MXATOM),
     .             C1(MXATOM),C2(MXATOM),COULS(MXATOM),COULP(MXATOM),
     .             COULD(MXATOM),X(MXATOM),Y(MXATOM),Z(MXATOM),
     .             KEY(MXATOM),AC(MXATOM),VELEC(MXATOM),NS(MXATOM),
     .             NP(MXATOM),ND(MXATOM)
      INTEGER AC,VELEC,KEY
 
      COMMON /STARS/STAR,STAR2,SYMBOL(MXATOM)
      CHARACTER*2 STAR,STAR2,SYMBOL
 
      COMMON /START/NUSER
      DATA SYMBOL/I0*'**','**','**','**','**','**','**','**',
     . '**','**','**','**','**','**','**','**','**','**','**',
     . ' C',' N',' O',' F','SI',' P',' S',
     . 'CL','LI','BE',' B','NA','MG','AL',' H','**','**','**',
     . '**','**'/
      DATA VELEC/I0*0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
     . 0,4,5,6,7,4,5,6,7,1,2,3,1,2,3,1,0,0,0,0,0/
      DATA NS/I0*0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
     . 2,2,2,2,3,3,3,3,2,2,2,3,3,3,1,0,0,0,0,0/
      DATA EXPS/I0*0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,0.0D0,0.0D0,1.625D0,1.950D0,2.275D0,2.425D0,
     . 1.383D0,1.6D0,1.817D0,2.033D0,0.65D0,0.975D0,1.3D0,0.733D0,
     . 0.95D0,1.167D0,1.3D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0/
      DATA COULS/I0*0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,-21.4D0,-26.0D0,-32.3D0,-40.0D0,-17.3D0,
     . -18.6D0,-20.0D0,-30.0D0,-5.4D0,-10.0D0,-15.2D0,-5.1D0,
     . -9.0D0,-12.3D0,-13.6D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0/
      DATA NP/I0*0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,2,2,
     . 3,3,3,3,2,2,2,3,3,3,0,0,0,0,0,0/
      DATA EXPP/I0*0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,1.625D0,1.950D0,2.275D0,2.425D0,1.383D0,
     . 1.6D0,1.817D0,2.033D0,0.65D0,0.975D0,1.3D0,0.733D0,0.95D0,
     . 1.167D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0/
      DATA COULP/I0*0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,-11.4D0,-13.4D0,-14.8D0,-18.1D0,-9.2D0,
     . -14.0D0,-13.3D0,-15.0D0,-3.5D0,-6.0D0,-8.5D0,-3.0D0,-4.5D0,
     . -6.5D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0/
      DATA ND/I0*0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
     . 3,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0/
      DATA EXPD/I0*0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,1.383D0,1.4D0,1.5D0,
     . 2.033D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,0.0D0,0.0D0,0.0D0/
      DATA COULD/I0*0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,-6.0D0,-7.0D0,-8.0D0,
     . -9.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,0.0D0,
     . 0.0D0,0.0D0,0.0D0,0.0D0,0.0D0/
      DATA C1/MXATOM*0.0D0/
      DATA C2/MXATOM*0.0D0/
      DATA EXPD2/MXATOM*0.0D0/
      DATA STAR,STAR2/' *','**'/
      DATA NUSER/MXITR1/
      END
 
C     ************************************************************
 
      IMPLICIT REAL*8(A-H,O-Z)
 
      INCLUDE 'iconpara.for'
 
      COMMON/TITLE/AB(10)
 
      COMMON/CNTRL/CON,PEEP,COULH,NH,NA,NATM,KA,NELEC,METH,IPRINT,
     .             IPUNCH,L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
      LOGICAL*1 L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
 
      COMMON/OUT/PRT(24),PUN(24),IOVPOP(24),IENRGY(24)
      INTEGER IOVPOP,IENRGY
      LOGICAL*1 PRT,PUN
 
      COMMON /ATOM/EXPS(MXATOM),EXPP(MXATOM),EXPD(MXATOM),EXPD2(MXATOM),
     .             C1(MXATOM),C2(MXATOM),COULS(MXATOM),COULP(MXATOM),
     .             COULD(MXATOM),X(MXATOM),Y(MXATOM),Z(MXATOM),
     .             KEY(MXATOM),AC(MXATOM),VELEC(MXATOM),NS(MXATOM),
     .             NP(MXATOM),ND(MXATOM)
      INTEGER AC,VELEC,KEY
 
      COMMON/ANEWDI/CWK,CWKALP,R(MXATOM,MXATOM)
 
      COMMON/ITPARM/DAMP1,DAMP2,DAMP3,LAMPRI,DELTAC,SENSE,MAXCYC,
     .              PRTCYC,ICYCLE,NCON,PARTIT,PRINTX,ITABLE(MXITER)
      REAL*8 LAMPRI
      LOGICAL*1 PARTIT,PRINTX,ITABLE
      INTEGER*4 PRTCYC
 
      COMMON/STARS/STAR,STAR2,SYMBOL(MXATOM)
      CHARACTER*2 STAR,STAR2,SYMBOL
C
C  23.10.90/mbs
C
C  FMO      : numbers of fragments attached to atoms
C  FMOCH    : charges of fragments
C  SORA,SORB: pointer indices to overlap integrals
C  NFRAG    : numbers of AOs per fragment
C  NUMBAT   : numbers of atoms per fragment, will be determined in FMOT
C  PRIFMO   : FMO print options
C
      COMMON/FMO/FMO(MXATOM),FMOCH(9),SORA(MXATOM),SORB(MXATOM),
     .           NFRAG(9),NUMBAT(9),IFMOPT(4*MXATOM),IBCKPT(MXATOM),
     .           PRIFMO(7)
      INTEGER FMO,FMOCH,SORA,SORB
      LOGICAL*1 PRIFMO

      COMMON/KSET/KATOM(MXSETK,2),SETK(MXSETK),SETD(MXSETK),NKSET
      INTEGER NKSET,KATOM
 
      COMMON/OMITRP/NOMIT,OMIT(MXOMIT)
      INTEGER NOMIT,OMIT
 
      LOGICAL*1 TEND
 
      WRITE(6,455)
455   FORMAT(' *******************************',
     *       '****************************'/
     *' *                    I C O N - E D i T                    *'/
     *' *                  Release September 1997                 *'/
     *' *                        I C O N C                        *'/
     *' *  -----------------------------------------------------  *'/
     *' *                    EHMO Calculation                     *'/
     *' *                          -----                          *'/
     *' *      Gion Calzaferri, Ruedi Rytz, Martin Braendle,      *'/
     *' *          Dominik Bruehwiler and Stephan Glaus           *'/
     *' *        Department of Chemistry and Biochemistry         *'/
     *' *             University of Bern, Switzerland             *'/
     *' *                                                         *'/
     *' *               (C) 1997 by Gion Calzaferri               *'/
     *' *  ICONC comes with absolutely no warranty. This is free  *'/
     *' *     software and you are welcome to redistribute it     *'/
     *' *                under certain conditions.                *'/
     *' *       For details see GNU General Public License.       *'/
     *' *******************************',
     *    '****************************'///)
C
C  Write energy levels into file ENERNI.DAT. This file can be read by
C  the Asyst program ENERNI.EHM, which makes a picture of the energy
C  levels.
C
      OPEN(UNIT=1,FILE='ENERNI.DAT',STATUS='UNKNOWN')
C
C  Prepare header for file ENERTOT.DAT with total energies.
C
      OPEN(UNIT=2,FILE='ENERTOT.DAT',STATUS='UNKNOWN')
      WRITE(2,100)
100   FORMAT('Title of ICONCL-Calculation             ',
     . '                Energies in eV: ',' Sum of1-Electr.',
     . '  Orbital. Stab.',' Core-Core Repul','  Stab. + Repul.',
     . /,'--------------------------------------------------',
     . '---------------------- --------------- ---------------',
     . ' --------------- ---------------'/)
C
C  Read in and print out input data.
C
      TEND=.FALSE.
1000  CALL INPUT(NATOM,NDIM,NTYPE,TEND)
      IF (TEND) GOTO 2000
      IF (IPRINT.LT.-3) GOTO 2000
C
C  Calculate matrix dimensions.
C
      NC=NDIM*(NDIM+1)/2
      NHS=NC+NC-NDIM
      NSS=NHS
C
C  If no wavefunctions needed, set nhs=0. this has the effect
C  of equivalencing the H and S matrices.
C
      ONEMAT=.FALSE.
      IF (.NOT.ITERAT.AND.IPRINT.LT.-1) ONEMAT=.TRUE.
      ONEMAT=.FALSE.
      IF (ONEMAT) NHS=0
      IF (METH.LT.3) NTYPE=1
      NMD=NTYPE*NTYPE
      NCL=NDIM
      IF (NDIM.LT.10) NCL=10
      NOCC=(NDIM+1)/2
      NHDG=1
      IF (METH.GT.2.AND.L5) NHDG=NDIM
C
C  Allocate space for matrices.
C  Order of matrices: H S MAD C SP PD MAXS MAXP MAXD COUL0 W IOCC HDG
C
C  Passing of size of SORB removed because it is passed by COMMON block
C  FMO. 24.10.90/mbs
C  Passing of size of W added. 30.10.90/mbs
C
200   CALL MATRIX(NHS,NSS,NMD,NC,NDIM,NDIM,NDIM,NDIM,2*NDIM,
     . NCL,NDIM,NOCC,NHDG, NDIM,   NC,NATOM,NTYPE,NHDG)
2000  CONTINUE
      WRITE(6,20)
20    FORMAT(////,T17,'* * * * * * * * * * * * * * * * * * * * * ',
     . '* * * * * * * * * * * * * * * * * * * * * * * * * * * * * ',
     . '* * *',///)
      IF (.NOT.TEND) GOTO 1000
      CLOSE(UNIT=1)
      CLOSE(UNIT=2)
      END
