C ********************************************************************
C * ICONC - Extended Hueckel Calculations                            *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE MATRIX                                               *
C *                                                                  *
C *  Routine of ICONC                                                *
C *                                                                  *
C *  Usage......: allocates variables for ICONC and sets pointers    *
C *               to them.                                           *
C *                                                                  *
C *  Authors....: -                                                  *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               University of Berne                                *
C *               Freiestrasse 3                                     *
C *               CH-3012 Berne                                      *
C *                                                                  *
C *  Date.......: -                                                  *
C *  Revision...: last revision 24.08.97/mbs (Martin Braendle)       *
C *  Remarks....: Allocation of FMO-matrices added. SORB removed,    *
C *               because it is passed by the COMMON block FMO./mbs  *
C *                                                                  *
C *  Called from: ICON                                               *
C *                                                                  *
C *  Calls......: MOVLAP                                             *
C *               HUCKEL                                             *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE MATRIX(NS1,NS2,NS3,NS4,NS5,NS6,NS7,NS8,NS9,NS10,
     . NS11,NS12,NS13, ND1,    ND3,ND4,ND5,ND6)
 
      IMPLICIT REAL*8(A-H,O-Z)
 
      INCLUDE 'iconpara.for'
 
      PARAMETER (NSIZE=72*MXATOM*MXATOM+40*MXATOM)
 
      COMMON/CNTRL/CON,PEEP,COULH,NH,NA,NATM,KA,NELEC,METH,IPRINT,
     .             IPUNCH,L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
      LOGICAL*1 L1,L2,L3,L4,L5,L6,L7,L8,L9,ONEMAT,ITERAT
 
      COMMON/FMO/FMO(MXATOM),FMOCH(9),SORA(MXATOM),SORB(MXATOM),
     .           NFRAG(9),NUMBAT(9),IFMOPT(4*MXATOM),IBCKPT(MXATOM),
     .           PRIFMO(7)
      INTEGER FMO,FMOCH,SORA,SORB
      LOGICAL*1 PRIFMO
C
C  Dimension NSIZE of the matrix A is calculated by approximately
C  4.5*N*N+10*N, with N=number of atom orbitals. It is assumed that each
C  atom in a worse (but not worst) case contributes 4 atomic orbitals.
C  Memory allocation is then 8*NSIZE (100 atoms -> 5.6 Megabytes).
C  If FMO is not used, there is about 1.8 times more matrix space left
C  for bigger systems (about 134 atoms).
C
C  NS1,A(I1)  : Hamiltonian matrix
C  NS2,A(I2)  : Overlap matrix
C  NS3,A(I3)  : Madelung parameters
C  NS4,A(I4)  : Wavefunction coefficients
C  NS5,A(I5)  : SP    diagonal elements of S etc.
C  NS6,A(I6)  : PD    used as temporal memory
C  NS7,A(I7)  : MAXS  used in MOVLAP
C  NS8,A(I8)  : MAXP  used in MOVLAP
C  NS9,A(I9)  : MAXD  used in MOVLAP
C  NS10,A(I10): COUL0
C  NS11,A(I11): W     used as temporal memory for level occupation
C  NS12,A(I12): IOCC  Occupation of levels
C  NS13,A(I13): Wavefunction coefficients for hydrogen atoms (not used)
C
C  ND1 = NDIM : Total number of AOs
C  ND3 = NC   : Size of triangle matrix of wavefunction coefficients
C  ND4 = NATOM: Number of atoms
C  ND5 = NTYPE: Sum of different AO types (s,p,d) over all atoms
C  ND6 = NHDG : Number of hydrogen atoms (=1, not used)
C
 
      DIMENSION A(NSIZE)
 
      DIMENSION NFRAG2(9)
      INTEGER NFRAG2
 
      I1=1
      I2=I1+NS1
      I3=I2+NS2
      I4=I3+NS3
      I5=I4+NS4
      I6=I5+NS5
      I7=I6+NS6
      I8=I7+NS7
      I9=I8+NS8
      I10=I9+NS9
      I11=I10+NS10
      I12=I11+NS11
      I13=I12+NS12
      IF=I13+NS13
C
C  Set pointers for FMO arrays. 24.10.90/mbs
C
C  First the pointers for the fragment hamiltonian matrices are set.
C  27.10.90/mbs, 31.01.91/mbs
C
      DO 10 I=1,9
        NFRAG2(I)=NFRAG(I)
        IF (NFRAG(I).LE.0) NFRAG2(I)=1
10    CONTINUE
 
      I14=IF
      I15=I14+NFRAG2(1)*NFRAG2(1)
      I16=I15+NFRAG2(2)*NFRAG2(2)
      I17=I16+NFRAG2(3)*NFRAG2(3)
      I18=I17+NFRAG2(4)*NFRAG2(4)
      I19=I18+NFRAG2(5)*NFRAG2(5)
      I20=I19+NFRAG2(6)*NFRAG2(6)
      I21=I20+NFRAG2(7)*NFRAG2(7)
      I22=I21+NFRAG2(8)*NFRAG2(8)
C
C  Then the pointers for the fragment overlap matrices are set. In
C  subroutine FMOSRT the fragment overlap matrices are overwritten by
C  the temporal array U of size (NDIM,NDIM). 27.10.90/mbs
C
      I23=I22+NFRAG2(9)*NFRAG2(9)
      I24=I23+NFRAG2(1)*NFRAG2(1)
      I25=I24+NFRAG2(2)*NFRAG2(2)
      I26=I25+NFRAG2(3)*NFRAG2(3)
      I27=I26+NFRAG2(4)*NFRAG2(4)
      I28=I27+NFRAG2(5)*NFRAG2(5)
      I29=I28+NFRAG2(6)*NFRAG2(6)
      I30=I29+NFRAG2(7)*NFRAG2(7)
      I31=I30+NFRAG2(8)*NFRAG2(8)
      IF =I31+NFRAG2(9)*NFRAG2(9)
 
      IF (IF.GT.NSIZE) GOTO 200
 
      CALL MOVLAP(A(I2),A(I3),A(I4),A(I5),A(I6),A(I7),A(I8),A(I9),
     . A(I10), ND1,ND3,ND4,ND5)
      CALL HUCKEL(A(I1),A(I2),A(I3),A(I4),A(I5),
     . A(I9),A(I10),A(I11),A(I12),A(I13), A(I14),A(I15),A(I16),A(I17),
     . A(I18),A(I19),A(I20),A(I21),A(I22), A(I23),A(I24),A(I25),A(I26),
     . A(I27),A(I28),A(I29),A(I30),A(I31),
     . ND1,    ND3,ND4,ND5,ND6, NFRAG2(1),NFRAG2(2),NFRAG2(3),NFRAG2(4),
     . NFRAG2(5),NFRAG2(6),NFRAG2(7),NFRAG2(8),NFRAG2(9))
      RETURN
 
 200  WRITE(6,1001) IF,NSIZE
 1001 FORMAT('0*** INSUFFICIENT SPACE FOR MATRICES'/'0PROGRAM REQUESTS'
     . ,I7,' DOUBLE WORDS BUT ONLY',I7,' ARE AVAILABLE'/'0RECOMPILE WITH
     . LARGER DIMENSION FOR A AND INCREASED VALUE OF NSIZE')
      RETURN
      END
