C ********************************************************************
C * INPUTC - Input Program for ICONC                                 *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE CONVC (originally PROGRAM CONVERTC)                  *
C *                                                                  *
C *  Routine of INPUTC                                               *
C *                                                                  *
C *  Usage......: Converts internal coordinates to cartesian.        *
C *                                                                  *
C *  WRITTEN : - J.M. HOWELL, CORNELL UNIVERSITY, USA, 1975 (?)      *
C *              (UNPUBLISHED PROGRAM)                               *
C *                                                                  *
C *  ORIGIN  : - CYBER 175 VERSION OF P. HOFMANN, MUENCHEN-GARCHING  *
C *              FORTRAN IV, OCT 1984, PROGRAM SCDNT                 *
C *                                                                  *
C *  VERSION : - IBM VERSION 1.1                                     *
C *            - ADAPTATIONS FOR IBM-PC COMPATIBLES                  *
C *              MICROSOFT FORTRAN COMPILER VERSION 4.10             *
C *              TH. HUGENTOBLER, AUGUST 1989                        *
C *              INST. FOR INORG. CHEMISTRY, UNIVERSITY CH-3012 BERN *
C *                                                                  *
C *  CHANGES :   NO ECHO TO CONSOLE (NO WRITE(6,...))  5.9.89 TH     *
C *                                                                  *
C *  Available..: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               Freiestrasse 3                                     *
C *               3012 Berne                                         *
C *                                                                  *
C *  Date.......: 5.9.89, by Thomas Hugentobler                      *
C *  Revision...: 15.05.92/rr//                                      *
C *  Remarks....: MOBYC added (explanation see GENIC.FOR).           *
C *               The name of FILE1 will be written at the bottom    *
C *               of the TEMP.KAR FILE (When MOBY - OUTPUT) is       *
C *               wished. This information will be needed in ICONC   *
C *               (MOBY.FOR)                                         *
C *               MOBYO is 'TRUE' when MOBY-OUTPUT is wished         *
C *                                                                  *
C *  Called from: INPUTC                                             *
C *                                                                  *
C *  Calls......: -                                                  *
C *                                                                  *
C ********************************************************************

      SUBROUTINE CONVC(FILEI,FILEO,MOBYC,FILE1)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      INCLUDE 'inpupara.for'

      CHARACTER*32 FILEI,FILEO,FILE1
      CHARACTER*80 AB,ABCOPY
      LOGICAL      MOBYO

      PARAMETER(NATOM1=MXATOM+1,MBYLOC=66)
C
C MBYLOC: Location of Moby flag. Must be changed if new calculation
C         and output options are included. 19.06.92/mbs
C
C
      DIMENSION DC(3,MXATOM),ETA(MXATOM),DEL(3),C(3,MXATOM),R(MXATOM),
     .          ZETA(MXATOM),NI(NATOM1),NF(MXATOM),NBACK(NATOM1)
      DATA DC(1,1),DC(3,2),DC(2,1),DC(3,1),DC(1,2),DC(2,2),ETA(2),
     .     ZETA(2),NI(2),NBACK(NATOM1)/-1.0,1.0,5*0.0,90.0,NATOM1,1/
      DATA MOBYO/.FALSE./

      FAC=3.14159265358979/180.0
        INFI=10

C
C UNIT INFI=10 FOR INPUT-FILE
C
      OPEN (UNIT=INFI,FILE=FILEI)

C
C UNIT 7 FOR OUTPUT-FILE
C
      OPEN (UNIT=7,FILE=FILEO,STATUS='UNKNOWN')
      WRITE(6,10) FILEI,FILEO
   10 FORMAT(//,' Conversion of Internal Coordinates from ',A32,/,
     .       ' to Cartesian Coordinates into ',A32,/' .....',$)
      COUNT=1

C
C  READ PARAMETERS FOR CONVERT
C
   20 READ(INFI,30,END=260) N,NDROP,NORD,NDIST
   30 FORMAT(4I4)
C
C READ TITLE CARD
C
      READ(INFI,40) AB
   40 FORMAT(A80)
      WRITE(7,40) AB
C
C READ PARAMETERS FOR ICON
C
      READ(INFI,50) AB
   50 FORMAT(A80)
      READ(AB,'(3X,I3)') NATOMS
      IF ((AB(MBYLOC:MBYLOC) .EQ. 'T') .AND. (COUNT .EQ. MOBYC)) THEN
        WRITE(7,50) AB
        MOBYO=.TRUE.
      ELSE
        COUNT=COUNT+1
        ABCOPY=AB(1:MBYLOC-1)//'F'//AB(MBYLOC+1:80)
        WRITE(7,50) ABCOPY
      ENDIF
C
C
C READ PARAMETERS FOR FMO (OR BLANK LINE)
C
      READ(INFI,50) AB
      WRITE(7,50) AB
C
C READ AND WRITE INTERNAL COORDINATES
C
      M=N+2
      NBOND=3
   60 READ(INFI,70) NI(NBOND),NF(NBOND),R(NBOND),ZETA(NBOND),ETA(NBOND)
   70 FORMAT(I3,1X,I3,3F10.5)
      NIT=NI(NBOND)
      IF (NBOND .NE. 3) GOTO 90
      NBACK(NIT)=2
      DO 80 I=1,3
        C(I,NIT)=0.0
   80 CONTINUE

   90 CONTINUE

      NFT=NF(NBOND)
      NBAK1=NBACK(NIT)
      NBACK(NFT)=NBOND
C
C TEST FOR A BONDANGLE OF 180 DEGREES
C
      TEST=ABS(ZETA(NBOND)-180.0)
      IF (TEST .GT. 0.000001) GOTO 100
      NBAK1=NBACK(NIT)
      DEL(1)=R(NBOND)*DC(1,NBAK1)
      DEL(2)=R(NBOND)*DC(2,NBAK1)
      DEL(3)=R(NBOND)*DC(3,NBAK1)
      GOTO 150
C
C NOW TEST FOR A BONDANGLE OF ZERO DEGREES
C
  100 TEST=ABS(ZETA(NBOND))
      IF (TEST .GT. 0.000001) GOTO 110
      DEL(1)= -R(NBOND)*DC(1,NBAK1)
      DEL(2)= -R(NBOND)*DC(2,NBAK1)
      DEL(3)= -R(NBOND)*DC(3,NBAK1)
      GOTO 150

  110 RS=R(NBOND)*SIN(ZETA(NBOND)*FAC)
      ALOC=RS*COS(ETA(NBOND)*FAC)
      BLOC=RS*SIN(ETA(NBOND)*FAC)
      CLOC=-R(NBOND)*COS(ZETA(NBOND)*FAC)
      NBK1SV=NBAK1
  120 NNIT=NI(NBAK1)
      NBAK2=NBACK(NNIT)
      ZETA1=ZETA(NBAK1)
      TEST=ABS(ZETA1-180.0)
      IF (TEST .LT. 0.000001) GOTO 130
      TEST=ABS(ZETA1)
      IF (TEST .GT. 0.000001) GOTO 140
  130 NBAK1=NBAK2
      GOTO 120
  140 ZETA1=ZETA1*FAC
      NBAK1=NBK1SV
      SINZ=SIN(ZETA1)
      ZETAA=ZETA1-1.5707963279489
      TANZ=SIN(ZETAA)/COS(ZETAA)
      DEL(1)=(TANZ*DC(1,NBAK1)-(DC(1,NBAK2)/SINZ))*ALOC+(DC(3,NBAK1)*
     .       DC(2,NBAK2)-DC(2,NBAK1)*DC(3,NBAK2))*BLOC/SINZ+DC(1,NBAK1)*
     .       CLOC
      DEL(2)=(TANZ*DC(2,NBAK1)-(DC(2,NBAK2)/SINZ))*ALOC+(DC(1,NBAK1)*
     .       DC(3,NBAK2)-DC(3,NBAK1)*DC(1,NBAK2))*BLOC/SINZ+DC(2,NBAK1)*
     .       CLOC
      DEL(3)=(TANZ*DC(3,NBAK1)-(DC(3,NBAK2)/SINZ))*ALOC+(DC(2,NBAK1)*
     .       DC(1,NBAK2)-DC(1,NBAK1)*DC(2,NBAK2))*BLOC/SINZ+DC(3,NBAK1)*
     .       CLOC
  150 DO 160 I=1,3
        DC(I,NBOND)=DEL(I)/R(NBOND)
        C(I,NFT)=DEL(I)+C(I,NIT)
  160 CONTINUE
      CK=0.0
      DO 170 I=1,3
        CK=CK+DEL(I)**2
  170 CONTINUE
      CK=SQRT(CK)
      N2=NBOND-2
      NBOND=NBOND+1
      IF (NBOND .LE. M) GOTO 60
      NA=N+1
      NADR=NA-NDROP
      WRITE(7,180) ((C(I,J),I=1,3),J=1,NADR)
  180 FORMAT(3F15.6)
C
C READ AND PUNCH ATOM DEFINION CARD
C
  190 READ(INFI,50) AB
      WRITE(7,50) AB
      NATOMS=NATOMS-40
      IF (NATOMS .GT. 0) GOTO 190
C
C READ AND PUNCH REST OF CARDS
C
      IF (NORD .GT. 0) THEN
        DO 200 LCL=1,NORD
          READ(INFI,50) AB
          WRITE(7,50) AB
  200   CONTINUE
      ENDIF
      GOTO 20

  260 CONTINUE
      CLOSE (UNIT=INFI)

      IF (MOBYO) THEN
        WRITE(7,' (A8) ') FILE1(1:(INDEX(FILE1,'.')-1))
      ENDIF

      CLOSE (UNIT=7)
      WRITE(6,270)
  270 FORMAT(' finished')
      RETURN
      END

