C ********************************************************************
C * INPUTC - Input Program for ICONC                                 *
C *                                                                  *
C * Copyright (C) 1997 by Gion Calzaferri                            *
C *                                                                  *
C * This program is free software; you can redistribute it and/or    *
C * modify it under the terms of the GNU General Public License as   *
C * published by the Free Software Foundation; Version 2 of the      *
C * License.                                                         *
C *                                                                  *
C * This program is distributed in the hope that it will be useful,  *
C * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
C * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU *
C * General Public License for more details.                         *
C *                                                                  *
C * You should have received a copy of the GNU General Public        *
C * License along with this program; if not, write to the Free       *
C * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
C * MA 02111-1307 USA                                                *
C ********************************************************************

C ********************************************************************
C *                                                                  *
C *  SUBROUTINE PARAMET                                              *
C *                                                                  *
C *  Routine of INPUTC                                               *
C *                                                                  *
C *  Usage......: reads special parameters                           *
C *                                                                  *
C *  Authors....: Calzaferri group c/o                               *
C *               Prof. Dr. Gion Calzaferri                          *
C *               Department of Chemistry and Biochemistry           *
C *               Freiestrasse 3                                     *
C *               3012 Berne                                         *
C *                                                                  *
C *  Date.......: 07.12.89, by Thomas Hugentobler                    *
C *  Revision...: last revisions 17.10.91/mbs (Martin Braendle)      *
C *                              25.05.92/rr  (Ruedi Rytz)           *
C *  Remarks....: Extended by FMO-option.                            *
C *               Extended by omit-atoms-for-repulsion-calculation   *
C *               option.                                            *
C *                                                                  *
C *  Called from: CASE1                                              *
C *                                                                  *
C *  Calls......: ITRATE                                             *
C *               OUT                                                *
C *               ORBSUB                                             *
C *               CWKA                                               *
C *               FMSPEC                                             *
C *               KSPEC                                              *
C *               OMITAT                                             *
C *                                                                  *
C ********************************************************************
 
      SUBROUTINE PARAMET
      IMPLICIT REAL(A-H,O-Z)
 
      INCLUDE 'inpupara.for'
 
      INTEGER CHOICE
 
      COMMON/ATDEF/IVELEC(MXSYMB),NS(MXSYMB),EXPS(MXSYMB),COULS(MXSYMB),
     .             NP(MXSYMB),EXPP(MXSYMB),COULP(MXSYMB),ND(MXSYMB),
     .             EXPD(MXSYMB),COULD(MXSYMB),C1(MXSYMB),EXPD2(MXSYMB),
     .             C2(MXSYMB)
 
      COMMON/PARAM/NH,NA,KA,METH,IPRINT,IPUNCH,L1,L2,L3,L4,L5,L6,L7,
     .             L8,L9,PRT
      LOGICAL L1,L2,L3,L4,L5,L6,L7,L8,L9,PRT(24)
 
   10 WRITE(6,20)
   20 FORMAT(/,16X,' MENU ',//,
     .    3X,' *************************************************** ',/,
     .    3X,' * 1  Charge iteration                             * ',/,
     .    3X,' * 2  Controlling output options                   * ',/,
     .    3X,' * 3  Orbital occupation                           * ',/,
     .    3X,' * 4  Individual 1+kappa and delta parameters      * ',/,
     .    3X,' * 5  Weighted Wolfsberg-Helmholz formula          * ',/,
     .    3X,' * 6  Simple Wolfsberg-Helmholz formula            * ',/,
     .    3X,' * 7  FMO (fragment molecular orbital) calculation * ',/,
     .    3X,' * 8  Omit atoms from repulsion energy calculation * ',/,
     .    3X,' * 9  Exit                                         * ',/,
     .    3X,' *************************************************** ',/)
      WRITE(6,30)
      READ(5,*,ERR=10) MQ
   30 FORMAT($,' Option #: ')
      IF (MQ .EQ. 1) THEN
        CALL ITRATE
      ELSE IF (MQ .EQ. 2) THEN
        CALL OUT
      ELSE IF (MQ .EQ. 3) THEN
C
C Calculate number of orbitals K3
C
        K3=0
        DO 40 I=1,NA
          IF (NS(I) .GT. 0) K3=K3+1
          IF (NP(I) .GT. 0) K3=K3+3
          IF (ND(I) .GT. 0) K3=K3+5
   40   CONTINUE
C
C Calclate number of electrons KELE
C
        KELE=0-KA
        DO 50 I=1,NA
          KELE=KELE+IVELEC(I)
   50   CONTINUE
        CALL ORBSUB(K3,KELE)
 
      ELSE IF (MQ .EQ. 4) THEN
        WRITE(6,' ( /, 5(3X, A, /)) ')
     .    '**********************************************************',
     .    '* 1  Set same parameters for all atoms                   *',
     .    '* 2  Specify different parameters for several atom pairs *',
     .    '* 3  Exit                                                *',
     .    '**********************************************************'
   60   WRITE(6,' (A, $) ') ' Option #: '
        READ(5,'(1I2) ',ERR=60) CHOICE
        IF (CHOICE .EQ. 1) THEN
          CALL CWKA
          IPUNCH=1
        ELSE IF (CHOICE .EQ. 2) THEN
          CALL KSPEC
        ELSE IF ((CHOICE .GT. 3) .OR. (CHOICE .LT. 1)) THEN
          GOTO 60
        ENDIF
 
      ELSE IF (MQ .EQ. 5) THEN
        L5=.TRUE.
        IPUNCH=0
      ELSE IF (MQ .EQ. 6) THEN
        L5=.FALSE.
        IPUNCH=0
 
      ELSE IF (MQ .EQ. 7) THEN
        CALL FMSPEC
 
      ELSE IF (MQ .EQ. 8) THEN
        CALL OMITAT
      ELSE
        RETURN
      ENDIF
      GOTO 10
      END
